Module commands

Module commands 

Structs

CommandDescription
Description of a command as returned by ListCommand
CommandLauncher
A command launcher will respond to RunCommand<TParameter, Result<TResponse, CommandError>> requests by spawning a task using a function. This is the typical way that a group of command queries is declared.
DescribeCommandRequest
Request to describe a particular command
DescribeCommandResponse
Provides a detailed description of what a command does
FnCommand
Basic type of a command that runs a function
ListCommandResponse
As part of a response to a list commands request, this indicates the name of a command supported by the sender. This is often used with a conversion into the response type of a command.
PipeCommand
A pipe command takes the output of one command and sends it to the input of another
ReadCommand
The read command just sends its input straight to its output (this is useful to read the result of a query when used with spawn_query)
RunCommand
The RunCommand is a query request that will run a named command with a parameter, returning the result as a stream of responses to a target

Enums

CommandError
An error that can be generated from a command

Constants

DESCRIBE_COMMAND
The name of the command sent to request a command description
LIST_COMMANDS
The name of the command sent to request the list command response

Functions

command_dispatcher_subprogram
Runs the command dispatcher subprogram for a particular type of command