pub struct DescribeCommandRequest(pub String);Expand description
Request to describe a particular command
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for DescribeCommandRequest
impl Clone for DescribeCommandRequest
Sourcefn clone(&self) -> DescribeCommandRequest
fn clone(&self) -> DescribeCommandRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DescribeCommandRequest
impl Debug for DescribeCommandRequest
Sourceimpl<'de> Deserialize<'de> for DescribeCommandRequest
impl<'de> Deserialize<'de> for DescribeCommandRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl SceneMessage for DescribeCommandRequest
impl SceneMessage for DescribeCommandRequest
Sourcefn default_target() -> StreamTarget
fn default_target() -> StreamTarget
The default target for this message type Read more
Sourcefn initialise(init_context: &impl SceneInitialisationContext)
fn initialise(init_context: &impl SceneInitialisationContext)
Sets up this message type in a scene. This can be an opportunity to set up default filters and connections for a
particular message type. This is called the first time that a message is referenced in a scene.
Sourcefn allow_thread_stealing_by_default() -> bool
fn allow_thread_stealing_by_default() -> bool
True if input streams for this message type should allow thread stealing by default Read more
Sourcefn serializable() -> bool
fn serializable() -> bool
True if this message supports serialization Read more
Sourcefn message_type_name() -> String
fn message_type_name() -> String
A string that identifies this message type uniquely when serializing Read more