ReadCommand

Struct ReadCommand 

pub struct ReadCommand<TInputType>(/* private fields */);
The read command just sends its input straight to its output (this is useful to read the result of a query when used with spawn_query)