serializer_filter

Function serializer_filter 

pub fn serializer_filter<TSourceType, TTargetType>() -> Result<Vec<FilterHandle>, &'static str>
where TSourceType: 'static + SceneMessage, TTargetType: 'static + SceneMessage,
If installed, returns the filters to use to convert from a source type to a target type

This will create either a serializer or a deserializer depending on the direction that the conversion goes in