A command launcher will respond to RunCommand<TParameter, Result<TResponse, CommandError>> requests by
spawning a task using a function. This is the typical way that a group of command queries is declared.
As part of a response to a list commands request, this indicates the name of a command supported by the sender. This
is often used with a conversion into the response type of a command.